==============================================
:mod:`numina.modeling` --- Model for fitting
==============================================

.. automodule:: numina.modeling
   :members:


.. automodule:: numina.modeling.enclosed
   :members:

.. automodule:: numina.modeling.gaussbox
   :members:

.. automodule:: numina.modeling.sumofgauss
   :members: